---
title: 'antispam:plugin:uridnsbl'
url: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-uridnsbl'
markdown: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-uridnsbl.md'
date: '2026-09-22'
description: 'Look up URLs in a message against DNS blocklists. warden --task=antispam:plugin:uridnsbl Option Value Default Description --skip_uribl_checks <1|0> 0 Turning on the skip_uribl_checks setting will disable the URIDNSBL plugin. --uridnsbl_max_domains <digit> 20 The maximum numbe…'
taxonomy:
  category:
    - docs
  tag:
    - uridnsbl
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Antispam       antispam:plugin:uridnsbl    

# antispam:plugin:uridnsbl

Look up URLs in a message against DNS blocklists.

```
warden --task=antispam:plugin:uridnsbl
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--skip_uribl_checks` | <1\|0> | 0 | Turning on the skip\_uribl\_checks setting will disable the URIDNSBL plugin. |
| `--uridnsbl_max_domains` | <digit> | 20 | The maximum number of domains to look up. |
| `--uridnsbl_skip_domain` | <string1,string2> |  | Specify a domain, or a number of domains, which should be skipped for the URIBL checks. This is very useful to specify very common domains which are not going to be listed in URIBLs. |
| `--uridnsbl_skip_domain_add` | <string> |  | Add a single entry to uridnsbl\_skip\_domain. |
| `--uridnsbl_skip_domain_del` | <string> |  | Remove a single entry from uridnsbl\_skip\_domain. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// disable uridnsbl checks
warden --task=antispam:plugin:uridnsbl --skip_uribl_checks=1 --reload=yes

// reset skip_uribl_checks to its default value
warden --task=antispam:plugin:uridnsbl --default_option=skip_uribl_checks --reload=yes

// reset all settings to their default values
warden --task=antispam:plugin:uridnsbl --default=yes --reload=yes
```

## Related Pages

- [URIDNSBL Settings](https://docs.danami.com/warden/settings/antispam/plugin-settings/uridnsbl "URIDNSBL Settings")
- [URIDNSBL](https://docs.danami.com/warden/user-guide/antispam-plugins/uridnsbl "URIDNSBL")

 [ ](https://docs.danami.com/warden/user-guide/antispam-plugins/uridnsbl) [](https://docs.danami.com/warden/settings/antispam/plugin-settings/uridnsbl)

---

## Navigation

- Previous: [antispam:plugin:txrep](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-txrep.md)
- Next: [antispam:plugin:urilocalbl](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-urilocalbl.md)
